import os
import ctypes
import glob
import serial
import time
import platform
import sys

def get_port(port=False):
    devices = []
    if not port:
        if os.name == 'nt':
            for i in range(15):
              try:
                s = serial.Serial('COM%d'%i)
                devices.append( s.portstr )
                s.close()
              except:
                pass
        else:
            ports = glob.glob('/dev/ttyUSB*') + glob.glob('/dev/ttyS*')
            for port in ports:
                port_obj = serial.Serial(
                    port = port,
                    baudrate = 9600,
                    bytesize = serial.EIGHTBITS,
                    parity = serial.PARITY_EVEN,
                    stopbits = serial.STOPBITS_ONE,
                    timeout = 0.5,
                    writeTimeout = 1.2,
                    xonxoff = 0,
                    rtscts = 0
                )
                if port_obj.isOpen():
                    devices.append( port )
                port_obj.close()
    else:
        devices.append( port )
    return devices

def get_driver(fname_driver=False):
    if not fname_driver:
        if os.name == 'posix':
            architecture = platform.architecture()
            if architecture[0] == '32bit':
                fname_driver = os.path.join(os.path.expanduser("~/.pyfiscal/lib"), "lib300fi32.so")
            elif architecture[0] == '64bit':
                fname_driver = os.path.join(os.path.expanduser("~/.pyfiscal/lib"), "lib300fi64.so")
        elif os.name == 'nt':
            fname_driver = "TODO"
    return fname_driver

def exec_driver(route, port=False):
    driver_pytxt = """
import os
#from ctypes import *
import ctypes
import glob
import serial
import time
import platform
import ctypes
""" + open(route,"r").read()

    ports = get_port()
    fname_driver = get_driver()
    port = ports and ports[0] or ''
    print port
    driver_obj = ctypes.cdll.LoadLibrary(fname_driver)
    exec driver_pytxt in {'port': port, 'fname_driver': fname_driver, 'driver_obj': driver_obj}

if __name__ == '__main__':
    script, route = sys.argv
    exec_driver(route)
